@@ -14,9 +14,7 @@ class MovieCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = MediaGroupViewModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -24,9 +22,7 @@ class ShowEpisodeCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = ShowEpisodeModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -34,9 +30,7 @@ class PlaylistCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = PlaylistModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -44,9 +38,7 @@ class TrackCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = TrackModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -54,9 +46,7 @@ class GenreCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = GenreModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -64,9 +54,7 @@ class ArtistCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = ArtistModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -74,9 +62,7 @@ class AlbumCategoryViewController: MediaCategoryViewController {
     init(_ services: Services) {
         let model = AlbumModel(medialibrary: services.medialibraryService)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
 
@@ -84,8 +70,6 @@ class CollectionCategoryViewController: MediaCategoryViewController {
     init(_ services: Services, mediaCollection: MediaCollectionModel) {
         let model = CollectionModel(mediaService: services.medialibraryService, mediaCollection: mediaCollection)
         super.init(services: services, model: model)
-        model.updateView = { [weak self] in
-            self?.reloadData()
-        }
+        model.observable.addObserver(self)
     }
 }
