@@ -2,7 +2,7 @@
  * VLCOpenNetworkStreamViewController.m
  * VLC for iOS
  *****************************************************************************
- * Copyright (c) 2013-2018 VideoLAN. All rights reserved.
+ * Copyright (c) 2013-2022 VideoLAN. All rights reserved.
  * $Id$
  *
  * Authors: Felix Paul Kühne <fkuehne # videolan.org>
@@ -15,7 +15,6 @@
 #import "VLCOpenNetworkStreamViewController.h"
 #import "VLCPlaybackService.h"
 #import "VLCStreamingHistoryCell.h"
-#import "UIDevice+VLC.h"
 #import "VLC-Swift.h"
 
 @interface VLCOpenNetworkStreamViewController () <UITableViewDataSource, UITableViewDelegate, UITextFieldDelegate, VLCStreamingHistoryCellMenuItemProtocol>
@@ -56,6 +55,11 @@
 
 - (void)ubiquitousKeyValueStoreDidChange:(NSNotification *)notification
 {
+    if (![NSThread isMainThread]) {
+        [self performSelectorOnMainThread:@selector(ubiquitousKeyValueStoreDidChange:) withObject:notification waitUntilDone:NO];
+        return;
+    }
+
     /* TODO: don't blindly trust that the Cloud knows best */
     _recentURLs = [NSMutableArray arrayWithArray:[[NSUbiquitousKeyValueStore defaultStore] arrayForKey:kVLCRecentURLs]];
     _recentURLTitles = [NSMutableDictionary dictionaryWithDictionary:[[NSUbiquitousKeyValueStore defaultStore] dictionaryForKey:kVLCRecentURLTitles]];
@@ -121,10 +125,12 @@
     [self.openButton setAccessibilityIdentifier:@"Open Network Stream"];
     self.openButton.layer.cornerRadius = 4.0;
     [self.privateModeLabel setText:NSLocalizedString(@"PRIVATE_PLAYBACK_TOGGLE", nil)];
-    UILabel *scanSubModelabel = self.ScanSubModeLabel;
-    [scanSubModelabel setText:NSLocalizedString(@"SCAN_SUBTITLE_TOGGLE", nil)];
-    [scanSubModelabel setAdjustsFontSizeToFitWidth:YES];
-    [scanSubModelabel setNumberOfLines:0];
+    [self.scanSubModeLabel setText:NSLocalizedString(@"SCAN_SUBTITLE_TOGGLE", nil)];
+
+    [self.privateToggleButton setImage:[UIImage imageNamed:@"iconCheckbox-checked"] forState:UIControlStateSelected];
+    [self.privateToggleButton setImage:[UIImage imageNamed:@"iconCheckbox-empty"] forState:UIControlStateNormal];
+    [self.scanSubToggleButton setImage:[UIImage imageNamed:@"iconCheckbox-checked"] forState:UIControlStateSelected];
+    [self.scanSubToggleButton setImage:[UIImage imageNamed:@"iconCheckbox-empty"] forState:UIControlStateNormal];
 
     [self.whatToOpenHelpLabel setText:NSLocalizedString(@"OPEN_NETWORK_HELP", nil)];
     self.urlField.delegate = self;
@@ -143,6 +149,8 @@
     [sharedMenuController setMenuItems:@[renameItem]];
     [sharedMenuController update];
     [self updateForTheme];
+
+    self.historyTableView.rowHeight = [VLCStreamingHistoryCell heightOfCell];
 }
 
 - (NSString *)detailText
@@ -157,17 +165,20 @@
 
 - (void)updateForTheme
 {
-    self.historyTableView.backgroundColor = PresentationTheme.current.colors.background;
-    self.view.backgroundColor = PresentationTheme.current.colors.background;
-    NSAttributedString *coloredAttributedPlaceholder = [[NSAttributedString alloc] initWithString:@"http://myserver.com/file.mkv" attributes:@{NSForegroundColorAttributeName: PresentationTheme.current.colors.lightTextColor}];
+    ColorPalette *colors = PresentationTheme.current.colors;
+    self.historyTableView.backgroundColor = colors.background;
+    self.view.backgroundColor = colors.background;
+    NSAttributedString *coloredAttributedPlaceholder = [[NSAttributedString alloc] initWithString:@"http://myserver.com/file.mkv" attributes:@{NSForegroundColorAttributeName: colors.textfieldPlaceholderColor}];
     self.urlField.attributedPlaceholder = coloredAttributedPlaceholder;
-    self.urlField.backgroundColor = PresentationTheme.current.colors.background;
-    self.urlField.textColor = PresentationTheme.current.colors.cellTextColor;
-    self.urlBorder.backgroundColor = PresentationTheme.current.colors.mediaCategorySeparatorColor;
-    self.privateModeLabel.textColor = PresentationTheme.current.colors.lightTextColor;
-    self.ScanSubModeLabel.textColor = PresentationTheme.current.colors.lightTextColor;
-    self.whatToOpenHelpLabel.textColor = PresentationTheme.current.colors.lightTextColor;
-    self.openButton.backgroundColor = PresentationTheme.current.colors.orangeUI;
+    self.urlField.backgroundColor = colors.mediaCategorySeparatorColor;
+    self.urlField.textColor = colors.cellTextColor;
+    self.urlBorder.backgroundColor = colors.textfieldBorderColor;
+    self.privateModeLabel.textColor = colors.lightTextColor;
+    self.scanSubModeLabel.textColor = colors.lightTextColor;
+    self.whatToOpenHelpLabel.textColor = colors.lightTextColor;
+    self.openButton.backgroundColor = colors.orangeUI;
+    self.privateToggleButton.tintColor = colors.orangeUI;
+    self.scanSubToggleButton.tintColor = colors.orangeUI;
     [self.historyTableView reloadData];
     [self setNeedsStatusBarAppearanceUpdate];
 }
@@ -187,8 +198,8 @@
 - (void)viewWillAppear:(BOOL)animated
 {
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-    self.privateToggleSwitch.on = [defaults boolForKey:kVLCPrivateWebStreaming];
-    self.ScanSubToggleSwitch.on = [defaults boolForKey:kVLChttpScanSubtitle];
+    self.privateToggleButton.selected = [defaults boolForKey:kVLCPrivateWebStreaming];
+    self.scanSubToggleButton.selected = [defaults boolForKey:kVLChttpScanSubtitle];
 
     [super viewWillAppear:animated];
 }
@@ -200,8 +211,8 @@
                                                   object:[UIApplication sharedApplication]];
 
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
-    [defaults setBool:self.privateToggleSwitch.on forKey:kVLCPrivateWebStreaming];
-    [defaults setBool:self.ScanSubToggleSwitch.on forKey:kVLChttpScanSubtitle];
+    [defaults setBool:self.privateToggleButton.selected forKey:kVLCPrivateWebStreaming];
+    [defaults setBool:self.scanSubToggleButton.selected forKey:kVLChttpScanSubtitle];
     [self.view endEditing:YES];
 
     /* force update before we leave */
@@ -223,6 +234,11 @@
     return YES;
 }
 
+- (IBAction)toggleButtonAction:(UIButton *)sender
+{
+    sender.selected = !sender.selected;
+}
+
 - (IBAction)openButtonAction:(id)sender
 {
     if ([self.urlField.text length] <= 0 || [NSURL URLWithString:self.urlField.text] == nil) {
@@ -231,7 +247,7 @@
                                            viewController:self];
         return;
     }
-    if (!self.privateToggleSwitch.on) {
+    if (!self.privateToggleButton.selected) {
         NSString *urlString = self.urlField.text;
         if ([_recentURLs indexOfObject:urlString] != NSNotFound)
             [_recentURLs removeObject:urlString];
@@ -295,6 +311,7 @@
         }];
     } else {
         [[NSUserDefaults standardUserDefaults] setObject:_recentURLTitles forKey:kVLCRecentURLTitles];
+        [self.historyTableView reloadSections:[NSIndexSet indexSetWithIndex:0] withRowAnimation:UITableViewRowAnimationAutomatic];
     }
 }
 
@@ -314,30 +331,22 @@
     static NSString *CellIdentifier = @"StreamingHistoryCell";
 
     VLCStreamingHistoryCell *cell = (VLCStreamingHistoryCell *)[tableView dequeueReusableCellWithIdentifier:CellIdentifier];
-    if (cell == nil) {
-        cell = [[VLCStreamingHistoryCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
-        cell.delegate = self;
-        [cell customizeAppearance];
-    }
+    if (cell == nil)
+        cell = (VLCStreamingHistoryCell *)[VLCStreamingHistoryCell cellWithReuseIdentifier:CellIdentifier];
 
     NSString *content = [_recentURLs[indexPath.row] stringByRemovingPercentEncoding];
     NSString *possibleTitle = _recentURLTitles[[@(indexPath.row) stringValue]];
 
-    cell.detailTextLabel.text = content;
-    cell.textLabel.text = possibleTitle ?: [content lastPathComponent];
+    cell.titleLabel.text = possibleTitle ?: [content lastPathComponent];
+    cell.subtitleLabel.text = content;
+    cell.thumbnailView.image = [UIImage imageNamed:@"serverIcon"];
+    cell.delegate = self;
 
     return cell;
 }
 
 #pragma mark - table view delegate
 
-- (void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath
-{
-    cell.backgroundColor = PresentationTheme.current.colors.cellBackgroundA;
-    cell.textLabel.textColor =  PresentationTheme.current.colors.cellTextColor;
-    cell.detailTextLabel.textColor =  PresentationTheme.current.colors.cellDetailTextColor;
-}
-
 - (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
 {
     return YES;
@@ -403,7 +412,7 @@ forRowAtIndexPath:(NSIndexPath *)indexPath
     NSURL *playbackURL = [NSURL URLWithString:url];
     NSURL *subtitlesURL = nil;
 
-    if (([playbackURL.scheme isEqualToString:@"http"] || [playbackURL.scheme isEqualToString:@"https"]) && self.ScanSubToggleSwitch.on) {
+    if (([playbackURL.scheme isEqualToString:@"http"] || [playbackURL.scheme isEqualToString:@"https"]) && self.scanSubToggleButton.selected) {
         subtitlesURL = [self _checkURLofSubtitle:playbackURL];
     }
 
